summaryrefslogtreecommitdiffhomepage
path: root/Private/Source/FileManager.cxx
diff options
context:
space:
mode:
authorAmlal El Mahrouss <amlal@el-mahrouss-logic.com>2024-03-18 12:35:19 +0100
committerAmlal El Mahrouss <amlal@el-mahrouss-logic.com>2024-03-18 12:39:24 +0100
commit4c714f2c24c5df78bae2f35c42c73107de4c8c71 (patch)
treeb36d2498b8387909dac45c98097b8169636ad25a /Private/Source/FileManager.cxx
parenta4bfc396a78ddd553de519ab927d8479d0c3c45d (diff)
unstable, unrelated: See below.
- :boom: Breaking changes in System.Core.dll - Framebuffer, moved operator bool into c++ source file. - Remove zlib in favor of our own Zip API. Signed-off-by: Amlal El Mahrouss <amlal@el-mahrouss-logic.com>
Diffstat (limited to 'Private/Source/FileManager.cxx')
-rw-r--r--Private/Source/FileManager.cxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/Private/Source/FileManager.cxx b/Private/Source/FileManager.cxx
index 7a09e5cf..4d3c9417 100644
--- a/Private/Source/FileManager.cxx
+++ b/Private/Source/FileManager.cxx
@@ -32,11 +32,11 @@ FilesystemManagerInterface* FilesystemManagerInterface::Unmount() {
}
/// @brief Mount filesystem.
/// @param pMount the filesystem to mount.
/// @return if it succeeded true, otherwise false.
-bool FilesystemManagerInterface::Mount(FilesystemManagerInterface* pMount) {
+bool FilesystemManagerInterface::Mount(FilesystemManagerInterface* mountPtr) {
if (kMounted == nullptr) {
- kMounted = pMount;
+ kMounted = mountPtr;
return true;
}
@@ -32,11 +32,11 @@ FilesystemManagerInterface* FilesystemManagerInterface::Unmount() {
}
/// @brief Mount filesystem.
-/// @param pMount the filesystem to mount.
+/// @param mountPtr the filesystem to mount.
/// @return if it succeeded true, otherwise false.